@@ -14,7 +14,7 @@
  * for more details.
  */
 
-char ipcomp_c_version[] = "RCSID $Id: ipcomp.c,v 1.41.2.5 2006/10/06 21:39:26 paul Exp $";
+char ipcomp_c_version[] = "RCSID $Id: ipcomp.c,v 1.41.2.8 2007-10-30 21:33:40 paul Exp $";
 
 /* SSS */
 
@@ -99,7 +99,7 @@ safe_skb_put(struct sk_buff *skb, int extend)
                 ptr = skb_put(skb, extend);
         } else {
                 // shrink the size of the packet
-                ptr = skb->tail;
+                ptr = skb_tail_pointer(skb);
                 skb_trim (skb, skb->len + extend);
         }
 
@@ -146,7 +146,7 @@ struct sk_buff *skb_compress(struct sk_buff *skb, struct ipsec_sa *ips, unsigned
 	}
 	
 #ifdef NET_21
-	iph = skb->nh.iph;
+	iph = ip_hdr(skb);
 #else /* NET_21 */
 	iph = skb->ip_hdr;
 #endif /* NET_21 */
@@ -372,7 +372,7 @@ struct sk_buff *skb_decompress(struct sk_buff *skb, struct ipsec_sa *ips, unsign
 	}
 	
 #ifdef NET_21
-	oiph = skb->nh.iph;
+	oiph = ip_hdr(skb);
 #else /* NET_21 */
 	oiph = skb->ip_hdr;
 #endif /* NET_21 */
@@ -491,7 +491,7 @@ struct sk_buff *skb_decompress(struct sk_buff *skb, struct ipsec_sa *ips, unsign
 #endif /* CONFIG_KLIPS_DEBUG */
 
 #ifdef NET_21
-	iph = nskb->nh.iph;
+	iph = ip_hdr(nskb);
 #else /* NET_21 */
 	iph = nskb->ip_hdr;
 #endif /* NET_21 */
@@ -598,14 +598,14 @@ struct sk_buff *skb_copy_ipcomp(struct sk_buff *skb, int data_growth, int gfp_ma
          */
 	
 #ifdef NET_21
-	iph = skb->nh.iph;
+	iph = ip_hdr(skb);
 #else /* NET_21 */
 	iph = skb->ip_hdr;
 #endif /* NET_21 */
         if (!iph) return NULL;
         iphlen = iph->ihl << 2;
-	
-        n=alloc_skb(skb->end - skb->head + data_growth, gfp_mask);
+
+        n=alloc_skb(skb_end_pointer(skb) - skb->head + data_growth, gfp_mask);
         if(n==NULL)
                 return NULL;
 	
@@ -630,16 +630,14 @@ struct sk_buff *skb_copy_ipcomp(struct sk_buff *skb, int data_growth, int gfp_ma
 	n->prev=NULL;
         n->sk=NULL;
         n->dev=skb->dev;
-	if (skb->h.raw)
-		n->h.raw=skb->h.raw+offset;
-	else
-		n->h.raw=NULL;
+	if (skb_transport_header(skb))
+		skb_set_transport_header(n, offset);
         n->protocol=skb->protocol;
 #ifdef NET_21
         n->csum = 0;
         n->priority=skb->priority;
         n->dst=dst_clone(skb->dst);
-        n->nh.raw=skb->nh.raw+offset;
+        skb_set_network_header(n, offset);
 #ifndef NETDEV_23
         n->is_clone=0;
 #endif /* NETDEV_23 */
@@ -670,10 +668,8 @@ struct sk_buff *skb_copy_ipcomp(struct sk_buff *skb, int data_growth, int gfp_ma
 	n->users=0;
 	memcpy(n->proto_priv, skb->proto_priv, sizeof(skb->proto_priv));
 #endif /* NET_21 */
-	if (skb->mac.raw)
-		n->mac.raw=skb->mac.raw+offset;
-	else
-		n->mac.raw=NULL;
+	if (skb_mac_header(skb))
+		skb_set_mac_header(n, offset);
 #ifndef NETDEV_23
 	n->used=skb->used;
 #endif /* !NETDEV_23 */
