@@ -13,7 +13,7 @@
  * for more details.
  */
 
-char ipsec_ah_c_version[] = "RCSID $Id: ipsec_ah.c,v 1.12.2.2 2006/10/06 21:39:26 paul Exp $";
+char ipsec_ah_c_version[] = "RCSID $Id: ipsec_ah.c,v 1.12.2.3 2007-09-05 02:56:09 paul Exp $";
 #ifndef AUTOCONF_INCLUDED
 #include <linux/config.h>
 #endif
@@ -75,7 +75,7 @@ ipsec_rcv_ah_checks(struct ipsec_rcv_state *irs,
 	ahminlen = irs->hard_header_len + sizeof(struct iphdr);
 
 	/* take care not to deref this pointer until we check the minlen though */
-	irs->protostuff.ahstuff.ahp = (struct ahhdr *)skb->h.raw;
+	irs->protostuff.ahstuff.ahp = (struct ahhdr *)skb_transport_header(skb);
 
 	if((skb->len < ahminlen+sizeof(struct ahhdr)) ||
 	   (skb->len < ahminlen+(irs->protostuff.ahstuff.ahp->ah_hl << 2))) {
@@ -163,7 +163,7 @@ ipsec_rcv_ah_authcalc(struct ipsec_rcv_state *irs,
 
 	/* finally, do the packet contents themselves */
 	(*aa->update)((void*)&tctx,
-		      (caddr_t)skb->h.raw + ahhlen,
+		      (caddr_t)skb_transport_header(skb) + ahhlen,
 		      skb->len - ahhlen);
 
 	(*aa->final)(irs->hash, (void *)&tctx);
@@ -194,8 +194,8 @@ ipsec_rcv_ah_decap(struct ipsec_rcv_state *irs)
 	 * move the IP header forward by the size of the AH header, which
 	 * will remove the the AH header from the packet.
 	 */
-	memmove((void *)(skb->nh.raw + ahhlen),
-		(void *)(skb->nh.raw), irs->iphlen);
+	memmove((void *)(skb_network_header(skb) + ahhlen),
+		(void *)(skb_network_header(skb)), irs->iphlen);
 
 	ipsec_rcv_dmp("ah postmove", skb->data, skb->len);
 
@@ -212,10 +212,10 @@ ipsec_rcv_ah_decap(struct ipsec_rcv_state *irs)
 	}
 	skb_pull(skb, ahhlen);
 
-	skb->nh.raw = skb->nh.raw + ahhlen;
-	irs->ipp = skb->nh.iph;
+	skb_set_network_header(skb, ahhlen);
+	irs->ipp = ip_hdr(skb);
 
-	ipsec_rcv_dmp("ah postpull", (void *)skb->nh.iph, skb->len);
+	ipsec_rcv_dmp("ah postpull", (void *)ip_hdr(skb), skb->len);
 
 	return IPSEC_RCV_OK;
 }
@@ -308,7 +308,7 @@ ipsec_xmit_ah_setup(struct ipsec_xmit_state *ixs)
     return IPSEC_XMIT_AH_BADALG;
   }
 #ifdef NET_21
-  ixs->skb->h.raw = (unsigned char*)ahp;
+  skb_set_transport_header(ixs->skb, ipsec_skb_offset(ixs->skb, ahp));
 #endif /* NET_21 */
 
   return IPSEC_XMIT_OK;
@@ -351,6 +351,10 @@ struct inet_protocol ah_protocol =
 
 /*
  * $Log: ipsec_ah.c,v $
+ * Revision 1.12.2.3  2007-09-05 02:56:09  paul
+ * Use the new ipsec_kversion macros by David to deal with 2.6.22 kernels.
+ * Fixes based on David McCullough patch.
+ *
  * Revision 1.12.2.2  2006/10/06 21:39:26  paul
  * Fix for 2.6.18+ only include linux/config.h if AUTOCONF_INCLUDED is not
  * set. This is defined through autoconf.h which is included through the
