@@ -13,14 +13,14 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: pfkey_v2_ext_process.c,v 1.20.2.3 2007-09-05 02:56:10 paul Exp $
+ * RCSID $Id: pfkey_v2_ext_process.c,v 1.20.2.4 2007-11-16 03:42:22 paul Exp $
  */
 
 /*
  *		Template from klips/net/ipsec/ipsec/ipsec_netlink.c.
  */
 
-char pfkey_v2_ext_process_c_version[] = "$Id: pfkey_v2_ext_process.c,v 1.20.2.3 2007-09-05 02:56:10 paul Exp $";
+char pfkey_v2_ext_process_c_version[] = "$Id: pfkey_v2_ext_process.c,v 1.20.2.4 2007-11-16 03:42:22 paul Exp $";
 
 #ifndef AUTOCONF_INCLUDED
 #include <linux/config.h>
@@ -403,8 +403,7 @@ pfkey_address_process(struct sadb_ext *pfkey_ext, struct pfkey_extracted_data* e
 			SENDERR(EPFNOSUPPORT);
 		}
 		{
-			unsigned long *ulsap = (unsigned long *)sap;
-			*ulsap = ((struct sockaddr_in*)s)->sin_addr.s_addr;
+			*(struct in_addr *)sap = ((struct sockaddr_in *)s)->sin_addr;
 		}
 
 		if (portp != 0)
@@ -862,7 +861,20 @@ errlab:
 
 /*
  * $Log: pfkey_v2_ext_process.c,v $
- * Revision 1.20.2.3  2007-09-05 02:56:10  paul
+ * Revision 1.20.2.4  2007-11-16 03:42:22  paul
+ * Fix for 64bit big endian machines where a cast for struct in_addr was
+ * wrong. This resulted in KLIPS dropping all NAT-T packets with the
+ * error:
+ *
+ * klips_debug:ipsec_xmit_SAlookup: checking for local udp/500 IKE packet
+ * saddr=a010c92, er=0p0000000000000000, daddr=a010f17, er_dst=0, proto=1
+ * sport=0 dport=0
+ * klips_debug:ipsec_xmit_encap_bundle: shunt SA of DROP or no eroute:
+ * dropping.
+ *
+ * Patch by [dhr]
+ *
+ * Revision 1.20.2.3  2007/09/05 02:56:10  paul
  * Use the new ipsec_kversion macros by David to deal with 2.6.22 kernels.
  * Fixes based on David McCullough patch.
  *
