@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: adns.c,v 1.11 2004/03/08 01:50:34 ken Exp $
+ * RCSID $Id: adns.c,v 1.11.24.1 2007-09-05 03:01:04 paul Exp $
  */
 
 #ifndef USE_LWRES	/* whole file! */
@@ -170,10 +170,16 @@ write_pipe(int fd, const unsigned char *stuff)
  * __RES was 19960801 in RHL6.2, an old resolver.
  */
 
+#undef OLD_RESOLVER
+
 #if (__RES) <= 19960801
 # define OLD_RESOLVER	1
 #endif
 
+#ifdef __UCLIBC__
+#define OLD_RESOLVER 1
+#endif
+
 #ifdef OLD_RESOLVER
 
 # define res_ninit(statp) res_init()
