@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: nat_traversal.h,v 1.4.8.2 2006-11-13 17:05:54 paul Exp $
+ * RCSID $Id: nat_traversal.h,v 1.4.8.3 2007-11-07 02:38:21 paul Exp $
  */
 
 #ifndef _NAT_TRAVERSAL_H_
@@ -21,8 +21,9 @@
 
 #define NAT_TRAVERSAL_IETF_00_01     1
 #define NAT_TRAVERSAL_IETF_02_03     2
-#define NAT_TRAVERSAL_OSX            3
-#define NAT_TRAVERSAL_RFC            4
+#define NAT_TRAVERSAL_IETF_05        3
+#define NAT_TRAVERSAL_OSX            4
+#define NAT_TRAVERSAL_RFC            5
 
 #define NAT_TRAVERSAL_NAT_BHND_ME    30
 #define NAT_TRAVERSAL_NAT_BHND_PEER  31
@@ -34,25 +35,25 @@
  */
 #define NAT_T_WITH_NATD \
 	( LELEM(NAT_TRAVERSAL_IETF_00_01) | LELEM(NAT_TRAVERSAL_IETF_02_03) | \
-	LELEM(NAT_TRAVERSAL_OSX) | LELEM(NAT_TRAVERSAL_RFC) )
+	LELEM(NAT_TRAVERSAL_IETF_05) | LELEM(NAT_TRAVERSAL_OSX) | LELEM(NAT_TRAVERSAL_RFC) )
 /**
  * NAT-Traversal methods which need NAT-OA
  */
 #define NAT_T_WITH_NATOA \
 	( LELEM(NAT_TRAVERSAL_IETF_00_01) | LELEM(NAT_TRAVERSAL_IETF_02_03) | \
-	LELEM(NAT_TRAVERSAL_RFC) )
+	LELEM(NAT_TRAVERSAL_IETF_05) | LELEM(NAT_TRAVERSAL_RFC) )
 /**
  * NAT-Traversal methods which use NAT-KeepAlive
  */
 #define NAT_T_WITH_KA \
 	( LELEM(NAT_TRAVERSAL_IETF_00_01) | LELEM(NAT_TRAVERSAL_IETF_02_03) | \
-	LELEM(NAT_TRAVERSAL_OSX) | LELEM(NAT_TRAVERSAL_RFC) )
+	LELEM(NAT_TRAVERSAL_IETF_05) | LELEM(NAT_TRAVERSAL_OSX) | LELEM(NAT_TRAVERSAL_RFC) )
 /**
  * NAT-Traversal methods which use floating port
  */
 #define NAT_T_WITH_PORT_FLOATING \
 	( LELEM(NAT_TRAVERSAL_IETF_02_03) | LELEM(NAT_TRAVERSAL_OSX) | \
-	LELEM(NAT_TRAVERSAL_RFC) )
+	LELEM(NAT_TRAVERSAL_IETF_05) | LELEM(NAT_TRAVERSAL_RFC) )
 
 /**
  * NAT-Traversal methods which use a value for NAT-D from draft versions of the
