@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: server.c,v 1.109.2.3 2006/07/20 15:36:25 ken Exp $
+ * RCSID $Id: server.c,v 1.109.2.4 2007-09-05 03:08:27 paul Exp $
  */
 
 #include <stdio.h>
@@ -340,8 +340,9 @@ static struct raw_iface *
 find_raw_ifaces(void)
 {
     int j;	/* index into buf */
+    int num;   /* number of interfaces */
     struct ifconf ifconf;
-    struct ifreq buf[300];	/* for list of interfaces -- arbitrary limit */
+    struct ifreq *buf; /* for list of interfaces */
     struct raw_iface *rifaces = NULL;
     int master_sock = socket(PF_INET, SOCK_DGRAM, IPPROTO_UDP);    /* Get a UDP socket */
 
@@ -364,16 +365,31 @@ find_raw_ifaces(void)
 	    exit_log_errno((e, "bind() failed in find_raw_ifaces()"));
     }
 
-    /* Get local interfaces.  See netdevice(7). */
-    ifconf.ifc_len = sizeof(buf);
-    ifconf.ifc_buf = (void *) buf;
-    zero(buf);
+    num = 100;
+    buf = NULL;
+    for (;;) {
+       /* Get local interfaces.  See netdevice(7). */
+       ifconf.ifc_len = num * sizeof(struct ifreq);
+       buf = (void *) realloc(buf, ifconf.ifc_len);
+       if (!buf)
+           exit_log_errno((e, "realloc of %d in find_raw_ifaces4()",
+                   ifconf.ifc_len));
+       memset(buf, 0, num*sizeof(struct ifreq));
+       ifconf.ifc_buf = (void *) buf;
 
-    if (ioctl(master_sock, SIOCGIFCONF, &ifconf) == -1)
-	exit_log_errno((e, "ioctl(SIOCGIFCONF) in find_raw_ifaces()"));
+       if (ioctl(master_sock, SIOCGIFCONF, &ifconf) == -1)
+           exit_log_errno((e, "ioctl(SIOCGIFCONF) in find_raw_ifaces4()"));
+
+       /* if we got back less than we asked for, we have them all */
+       if (ifconf.ifc_len < (int)(sizeof(struct ifreq) * num))
+           break;
+
+       /* try again and ask for more this time */
+       num += 100;
+    }
 
     /* Add an entry to rifaces for each interesting interface. */
-    for (j = 0; (j+1) * sizeof(*buf) <= (size_t)ifconf.ifc_len; j++)
+    for (j = 0; (j+1) * sizeof(struct ifreq) <= (size_t)ifconf.ifc_len; j++)
     {
 	struct raw_iface ri;
 	const struct sockaddr_in *rs = (struct sockaddr_in *) &buf[j].ifr_addr;
@@ -426,6 +442,9 @@ find_raw_ifaces(void)
 
     close(master_sock);
 
+    if (buf)
+       free(buf);
+
     return rifaces;
 }
 
