@@ -6,9 +6,11 @@ TESTHOST=east
 EXITONEMPTY=--exitonempty
 PRIVINPUT=../inputs/01-sunrise-sunset-ping.pcap
 #PRIVINPUT=../inputs/ikeinit-sunrise-sunset.pcap
-REFPUBOUTPUT=spi1-output.txt
-REFCONSOLEOUTPUT=spi1-console.txt
+REF_PUB_OUTPUT=spi1-output.txt
+REF_CONSOLE_OUTPUT=spi1-console.txt
+REF26_CONSOLE_OUTPUT=spi1-console26.txt
 REF_CONSOLE_FIXUPS="kern-list-fixups.sed nocr.sed"
+REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS script-only.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS klips-spi-sanitize.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS ipsec-look-sanitize.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS east-prompt-splitline.pl"
