@@ -1,3 +1,5 @@
+: ==== start ====
+
 #ipsec setup stop
 #umount /var/tmp; mount /var/tmp
 #umount /usr/local && mount /usr/local
@@ -14,7 +16,7 @@ source /testing/pluto/bin/westlocal.sh
 
 ipsec setup start
 ipsec auto --add westnet-eastnet-aggr-psk
-/testing/pluto/basic-pluto-01/eroutewait.sh trap
+/testing/pluto/bin/wait-until-pluto-started
 ipsec auto --up  westnet-eastnet-aggr-psk
 
 echo done
