@@ -1,7 +1,6 @@
 #!/bin/sh
 
-TEST_PURPOSE=regress
-TEST_PROB_REPORT=0
+TEST_PURPOSE=goal
 TEST_TYPE=umlplutotest
 
 TESTNAME=basic-pluto-04
@@ -14,9 +13,12 @@ WEST_ARPREPLY=true
 THREEEIGHT=true
 
 REF_EAST_CONSOLE_OUTPUT=east-console.txt
+REF26_EAST_CONSOLE_OUTPUT=east-console.txt
 REF_WEST_CONSOLE_OUTPUT=west-console.txt
+REF26_WEST_CONSOLE_OUTPUT=west-console.txt
 
 REF_CONSOLE_FIXUPS="kern-list-fixups.sed nocr.sed"
+REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS script-only.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS east-prompt-splitline.pl"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS cutout.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS klips-debug-sanitize.sed"
