@@ -4,7 +4,7 @@ TEST_PURPOSE=regress
 TEST_PROB_REPORT=0
 TEST_TYPE=umlplutotest
 
-TESTNAME=fail-x509-08
+TESTNAME=fail-x509-09
 EASTHOST=east
 WESTHOST=west
 
@@ -29,12 +29,12 @@ REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS ipsec-look-esp-sanitize.pl"
 EAST_INIT_SCRIPT=eastinit.sh
 WEST_INIT_SCRIPT=westinit.sh
 
-WEST_RUN_SCRIPT=../x509-pluto-03/westrun.sh
+WEST_RUN_SCRIPT=westrun.sh
 
-EAST_FINAL_SCRIPT=../x509-pluto-03/final.sh
-WEST_FINAL_SCRIPT=../x509-pluto-03/final.sh
+EAST_FINAL_SCRIPT=final.sh
+WEST_FINAL_SCRIPT=final.sh
 
-NETJIG_EXTRA=../x509-pluto-03/debugpublic.txt
+NETJIG_EXTRA=../basic-pluto-01/debugpublic.txt
 
 
 
