@@ -1,15 +1,15 @@
 #!/usr/bin/expect --
 
 #
-# $Id: localswitches.tcl,v 1.3.8.1 2004/03/21 05:23:51 mcr Exp $
+# $Id: localswitches.tcl,v 1.5 2004-04-03 19:44:52 ken Exp $
 #
 
-source $env(FREESWANSRCDIR)/testing/utils/GetOpts.tcl
-source $env(FREESWANSRCDIR)/testing/utils/netjig.tcl
+source $env(OPENSWANSRCDIR)/testing/utils/GetOpts.tcl
+source $env(OPENSWANSRCDIR)/testing/utils/netjig.tcl
 
 set netjig_debug_opt ""
 
-set netjig_prog $env(FREESWANSRCDIR)/testing/utils/uml_netjig/uml_netjig
+set netjig_prog $env(OPENSWANSRCDIR)/testing/utils/uml_netjig/uml_netjig
 
 set arpreply ""
 set umlid(extra_hosts) ""
